@@ -26,15 +26,15 @@ Triweight <- R6Class("Triweight",
     #' where X is the Distribution, \eqn{f_X} is its pdf and \eqn{a, b}
     #' are the distribution support limits.
     pdfSquared2Norm = function(x = 0, upper = Inf) {
-      xl = length(x)
-      ul = length(upper)
-      len = max(xl, ul)
+      xl <- length(x)
+      ul <- length(upper)
+      len <- max(xl, ul)
 
       ret <- numeric(len)
       for (i in seq(len)) {
 
-        xi = x[ifelse(i %% xl == 0, xl, i %% xl)]
-        ui = upper[ifelse(i %% ul == 0, ul, i %% ul)]
+        xi <- x[ifelse(i %% xl == 0, xl, i %% xl)]
+        ui <- upper[ifelse(i %% ul == 0, ul, i %% ul)]
 
         if (abs(xi) >= 2) {
           ret[i] <- 0
@@ -99,15 +99,15 @@ Triweight <- R6Class("Triweight",
     #' are the distribution support limits.
     cdfSquared2Norm = function(x = 0, upper = 0) {
 
-      xl = length(x)
-      ul = length(upper)
-      len = max(xl, ul)
+      xl <- length(x)
+      ul <- length(upper)
+      len <- max(xl, ul)
 
       ret <- numeric(len)
       for (i in seq(len)) {
 
-        xi = x[ifelse(i %% xl == 0, xl, i %% xl)]
-        ui = upper[ifelse(i %% ul == 0, ul, i %% ul)]
+        xi <- x[ifelse(i %% xl == 0, xl, i %% xl)]
+        ui <- upper[ifelse(i %% ul == 0, ul, i %% ul)]
 
         if (xi >= 0 & xi <= 2) {
           if (ui <= - 1) {
